@@ -1079,9 +1079,9 @@ grl_net_wc_set_cache (GrlNetWc *self,
 {
   g_return_if_fail (GRL_IS_NET_WC (self));
 
-  if (use_cache)
+  if (use_cache && !cache_is_available (self))
     cache_up (self);
-  else
+  else if (!use_cache && cache_is_available (self))
     cache_down (self);
 }
 
@@ -1122,16 +1122,16 @@ grl_net_wc_set_cache_size (GrlNetWc *self,
 void
 grl_net_wc_flush_delayed_requests (GrlNetWc *self)
 {
-  g_return_if_fail (GRL_IS_NET_WC (self));
-
   GrlNetWcPrivate *priv = self->priv;
   struct request_clos *c;
 
+  g_return_if_fail (GRL_IS_NET_WC (self));
+
   while ((c = g_queue_pop_head (priv->pending))) {
+    if (c->cancellable)
+      g_cancellable_cancel (c->cancellable);
+    /* This will call the destroy notify, request_clos_destroy()  */
     g_source_remove (c->source_id);
-    g_object_unref (c->cancellable);
-    g_free (c->url);
-    g_free (c);
   }
 
   g_get_current_time (&priv->last_request);
