@@ -764,7 +764,7 @@ multiple_result_async_cb (GrlSource *source,
 /**
  * grl_pls_browse_by_spec:
  * @source: a source
- * @filter_func: (scope async): A filter function
+ * @filter_func: (scope async): A filter function, or %NULL
  * @bs: a GrlSourceBrowseSpec structure with details of the browsing operation
  *
  * Browse into a playlist. The playlist entries are
@@ -869,7 +869,7 @@ grl_pls_browse_by_spec (GrlSource *source,
  * @keys: (element-type GrlKeyID): the #GList of
  * #GrlKeyID<!-- -->s to request
  * @options: options wanted for that operation
- * @filter_func: (scope async): A filter function
+ * @filter_func: (scope async): A filter function, or %NULL
  * @callback: (scope notified): the user defined callback
  * @user_data: the user data to pass in the callback
  *
@@ -939,7 +939,7 @@ grl_pls_browse (GrlSource *source,
  * @playlist: a playlist
  * @keys: (element-type GrlKeyID): the #GList of
  * #GrlKeyID<!-- -->s to request
- * @filter_func: (scope async): A filter function
+ * @filter_func: (scope async): A filter function, or %NULL
  * @options: options wanted for that operation
  * @error: a #GError, or @NULL
  *
@@ -1258,6 +1258,7 @@ grl_pls_file_to_media (GrlMedia            *content,
     }
 
     grl_media_set_title (media, str);
+    grl_data_set_boolean (GRL_DATA (media), GRL_METADATA_KEY_TITLE_FROM_FILENAME, TRUE);
     g_clear_error (&error);
     g_free (str);
   } else {
@@ -1315,6 +1316,8 @@ grl_pls_file_to_media (GrlMedia            *content,
     grl_media_set_title (media, str);
     g_free (str);
 
+    grl_data_set_boolean (GRL_DATA (media), GRL_METADATA_KEY_TITLE_FROM_FILENAME, TRUE);
+
     /* Date */
     g_file_info_get_modification_time (info, &time);
     date_time = g_date_time_new_from_timeval_utc (&time);
