@@ -34,7 +34,6 @@
 #include "grl-media-video.h"
 
 
-static void grl_media_video_dispose (GObject *object);
 static void grl_media_video_finalize (GObject *object);
 
 G_DEFINE_TYPE (GrlMediaVideo, grl_media_video, GRL_TYPE_MEDIA);
@@ -44,7 +43,6 @@ grl_media_video_class_init (GrlMediaVideoClass *klass)
 {
   GObjectClass *gobject_class = (GObjectClass *)klass;
 
-  gobject_class->dispose = grl_media_video_dispose;
   gobject_class->finalize = grl_media_video_finalize;
 }
 
@@ -53,12 +51,6 @@ grl_media_video_init (GrlMediaVideo *self)
 {
 }
 
-static void
-grl_media_video_dispose (GObject *object)
-{
-  G_OBJECT_CLASS (grl_media_video_parent_class)->dispose (object);
-}
-
 static void
 grl_media_video_finalize (GObject *object)
 {
@@ -97,6 +89,8 @@ grl_media_video_set_size (GrlMediaVideo *video,
                           gint width,
                           int height)
 {
+  g_return_if_fail (GRL_IS_MEDIA_VIDEO (video));
+
   grl_media_video_set_width (video, width);
   grl_media_video_set_height (video, height);
 }
@@ -302,7 +296,11 @@ grl_media_video_set_url_data (GrlMediaVideo *video,
                               gint width,
                               gint height)
 {
-  GrlRelatedKeys *relkeys = grl_related_keys_new ();
+  GrlRelatedKeys *relkeys;
+
+  g_return_if_fail (GRL_IS_MEDIA_VIDEO (video));
+
+  relkeys = grl_related_keys_new ();
   grl_related_keys_set_string (relkeys, GRL_METADATA_KEY_URL, url);
   grl_related_keys_set_string (relkeys, GRL_METADATA_KEY_MIME, mime);
   if (framerate >= 0) {
@@ -339,7 +337,11 @@ grl_media_video_add_url_data (GrlMediaVideo *video,
                               gint width,
                               gint height)
 {
-  GrlRelatedKeys *relkeys = grl_related_keys_new ();
+  GrlRelatedKeys *relkeys;
+
+  g_return_if_fail (GRL_IS_MEDIA_VIDEO (video));
+
+  relkeys = grl_related_keys_new ();
   grl_related_keys_set_string (relkeys, GRL_METADATA_KEY_URL, url);
   grl_related_keys_set_string (relkeys, GRL_METADATA_KEY_MIME, mime);
   if (framerate >= 0) {
@@ -403,7 +405,11 @@ grl_media_video_get_url_data_nth (GrlMediaVideo *video,
                                   gint *width,
                                   gint *height)
 {
-  GrlRelatedKeys *relkeys =
+  GrlRelatedKeys *relkeys;
+
+  g_return_val_if_fail (GRL_IS_MEDIA_VIDEO (video), NULL);
+
+  relkeys =
     grl_data_get_related_keys (GRL_DATA (video), GRL_METADATA_KEY_URL, index);
 
   if (!relkeys) {
@@ -495,7 +501,11 @@ const gchar *
 grl_media_video_get_performer_nth (GrlMediaVideo *video,
                                    guint index)
 {
-  GrlRelatedKeys *const relkeys =
+  GrlRelatedKeys *relkeys;
+
+  g_return_val_if_fail (GRL_IS_MEDIA_VIDEO (video), NULL);
+
+  relkeys =
     grl_data_get_related_keys (GRL_DATA (video),
                                GRL_METADATA_KEY_PERFORMER,
                                index);
@@ -572,7 +582,11 @@ const gchar *
 grl_media_video_get_producer_nth (GrlMediaVideo *video,
                                   guint index)
 {
-  GrlRelatedKeys *const relkeys =
+  GrlRelatedKeys *relkeys;
+
+  g_return_val_if_fail (GRL_IS_MEDIA_VIDEO (video), NULL);
+
+  relkeys =
     grl_data_get_related_keys (GRL_DATA (video),
                                GRL_METADATA_KEY_PRODUCER,
                                index);
@@ -649,7 +663,11 @@ const gchar *
 grl_media_video_get_director_nth (GrlMediaVideo *video,
                                   guint index)
 {
-  GrlRelatedKeys *const relkeys =
+  GrlRelatedKeys *relkeys;
+
+  g_return_val_if_fail (GRL_IS_MEDIA_VIDEO (video), NULL);
+
+  relkeys =
     grl_data_get_related_keys (GRL_DATA (video),
                                GRL_METADATA_KEY_DIRECTOR,
                                index);
