@@ -285,6 +285,8 @@ grl_related_keys_set_string (GrlRelatedKeys *relkeys,
 {
   GValue value = { 0 };
 
+  g_return_if_fail (GRL_IS_RELATED_KEYS (relkeys));
+
   if (strvalue) {
     g_value_init (&value, G_TYPE_STRING);
     g_value_set_string (&value, strvalue);
@@ -310,7 +312,11 @@ const gchar *
 grl_related_keys_get_string (GrlRelatedKeys *relkeys,
                              GrlKeyID key)
 {
-  const GValue *value = grl_related_keys_get (relkeys, key);
+  const GValue *value;
+
+  g_return_val_if_fail (GRL_IS_RELATED_KEYS (relkeys), NULL);
+
+  value = grl_related_keys_get (relkeys, key);
 
   if (!value || !G_VALUE_HOLDS_STRING (value)) {
     return NULL;
@@ -336,6 +342,7 @@ grl_related_keys_set_int (GrlRelatedKeys *relkeys,
                           gint intvalue)
 {
   GValue value = { 0 };
+  g_return_if_fail (GRL_IS_RELATED_KEYS (relkeys));
   g_value_init (&value, G_TYPE_INT);
   g_value_set_int (&value, intvalue);
   grl_related_keys_set (relkeys, key, &value);
@@ -357,7 +364,11 @@ gint
 grl_related_keys_get_int (GrlRelatedKeys *relkeys,
                           GrlKeyID key)
 {
-  const GValue *value = grl_related_keys_get (relkeys, key);
+  const GValue *value;
+
+  g_return_val_if_fail (GRL_IS_RELATED_KEYS (relkeys), 0);
+
+  value = grl_related_keys_get (relkeys, key);
 
   if (!value || !G_VALUE_HOLDS_INT (value)) {
     return 0;
@@ -383,6 +394,7 @@ grl_related_keys_set_float (GrlRelatedKeys *relkeys,
                             float floatvalue)
 {
   GValue value = { 0 };
+  g_return_if_fail (GRL_IS_RELATED_KEYS (relkeys));
   g_value_init (&value, G_TYPE_FLOAT);
   g_value_set_float (&value, floatvalue);
   grl_related_keys_set (relkeys, key, &value);
@@ -404,7 +416,11 @@ gfloat
 grl_related_keys_get_float (GrlRelatedKeys *relkeys,
                             GrlKeyID key)
 {
-  const GValue *value = grl_related_keys_get (relkeys, key);
+  const GValue *value;
+
+  g_return_val_if_fail (GRL_IS_RELATED_KEYS (relkeys), 0.0);
+
+  value = grl_related_keys_get (relkeys, key);
 
   if (!value || !G_VALUE_HOLDS_FLOAT (value)) {
     return 0;
@@ -430,6 +446,7 @@ grl_related_keys_set_boolean (GrlRelatedKeys *relkeys,
                               gboolean booleanvalue)
 {
   GValue value = { 0 };
+  g_return_if_fail (GRL_IS_RELATED_KEYS (relkeys));
   g_value_init (&value, G_TYPE_BOOLEAN);
   g_value_set_boolean (&value, booleanvalue);
   grl_related_keys_set (relkeys, key, &value);
@@ -452,7 +469,11 @@ gboolean
 grl_related_keys_get_boolean (GrlRelatedKeys *relkeys,
                               GrlKeyID key)
 {
-  const GValue *value = grl_related_keys_get (relkeys, key);
+  const GValue *value;
+
+  g_return_val_if_fail (GRL_IS_RELATED_KEYS (relkeys), NULL);
+
+  value = grl_related_keys_get (relkeys, key);
 
   if (!value || !G_VALUE_HOLDS_BOOLEAN (value)) {
     return FALSE;
@@ -482,6 +503,8 @@ grl_related_keys_set_binary (GrlRelatedKeys *relkeys,
   GValue v = { 0 };
   GByteArray *array;
 
+  g_return_if_fail (GRL_IS_RELATED_KEYS (relkeys));
+
   if (!buf || !size) {
     return;
   }
@@ -515,9 +538,13 @@ grl_related_keys_get_binary (GrlRelatedKeys *relkeys,
                              GrlKeyID key,
                              gsize *size)
 {
+  const GValue *value;
+
+  g_return_val_if_fail (GRL_IS_RELATED_KEYS (relkeys), NULL);
   g_return_val_if_fail (size, NULL);
 
-  const GValue *value = grl_related_keys_get (relkeys, key);
+  value = grl_related_keys_get (relkeys, key);
+
 
   if (!value || !G_VALUE_HOLDS_BOXED (value)) {
     return NULL;
@@ -548,6 +575,7 @@ grl_related_keys_set_boxed (GrlRelatedKeys *relkeys,
 {
   GValue value = { 0 };
 
+  g_return_if_fail (GRL_IS_RELATED_KEYS (relkeys));
   g_return_if_fail (boxed != NULL);
 
   g_value_init (&value, grl_metadata_key_get_type (key));
@@ -575,7 +603,11 @@ gconstpointer
 grl_related_keys_get_boxed (GrlRelatedKeys *relkeys,
                             GrlKeyID key)
 {
-  const GValue *value = grl_related_keys_get (relkeys, key);
+  const GValue *value;
+
+  g_return_val_if_fail (GRL_IS_RELATED_KEYS (relkeys), NULL);
+
+  value = grl_related_keys_get (relkeys, key);
 
   if (!value || !G_VALUE_HOLDS_BOXED (value)) {
     return NULL;
@@ -664,7 +696,7 @@ grl_related_keys_dup (GrlRelatedKeys *relkeys)
   GValue *value_copy;
   GrlRelatedKeys *dup_relkeys;
 
-  g_return_val_if_fail (relkeys, NULL);
+  g_return_val_if_fail (GRL_IS_RELATED_KEYS (relkeys), NULL);
 
   dup_relkeys = grl_related_keys_new ();
 
