@@ -79,7 +79,7 @@ struct _GrlRegistryPrivate {
   GHashTable *plugins;
   GHashTable *sources;
   GHashTable *related_keys;
-  GParamSpecPool *system_keys;
+  GHashTable *system_keys;
   GHashTable *ranks;
   GSList *plugins_dir;
   GSList *allowed_plugins;
@@ -87,8 +87,6 @@ struct _GrlRegistryPrivate {
   struct KeyIDHandler key_id_handler;
 };
 
-static void grl_registry_finalize (GObject *object);
-
 static void grl_registry_setup_ranks (GrlRegistry *registry);
 
 static void grl_registry_preload_plugins (GrlRegistry *registry,
@@ -109,11 +107,14 @@ static GrlKeyID key_id_handler_add (struct KeyIDHandler *handler,
 
 static void shutdown_plugin (GrlPlugin *plugin);
 
+static void configs_free (GList *configs);
+
 /* ================ GrlRegistry GObject ================ */
 
 enum {
   SIG_SOURCE_ADDED,
   SIG_SOURCE_REMOVED,
+  SIG_METADATA_KEY_ADDED,
   SIG_LAST
 };
 static gint registry_signals[SIG_LAST];
@@ -123,14 +124,8 @@ G_DEFINE_TYPE (GrlRegistry, grl_registry, G_TYPE_OBJECT);
 static void
 grl_registry_class_init (GrlRegistryClass *klass)
 {
-  GObjectClass *gobject_klass;
-
   g_type_class_add_private (klass, sizeof (GrlRegistryPrivate));
 
-  gobject_klass = G_OBJECT_CLASS (klass);
-
-  gobject_klass->finalize = grl_registry_finalize;
-
   /**
    * GrlRegistry::source-added:
    * @registry: the registry
@@ -168,6 +163,25 @@ grl_registry_class_init (GrlRegistryClass *klass)
 		 NULL,
 		 g_cclosure_marshal_VOID__OBJECT,
 		 G_TYPE_NONE, 1, GRL_TYPE_SOURCE);
+
+  /**
+   * GrlRegistry::metadata-key-added:
+   * @registry: the registry
+   * @key: the name of the new key added
+   *
+   * Signals that a new metadata key has been registered.
+   *
+   * Since: 0.2.10
+   */
+  registry_signals[SIG_METADATA_KEY_ADDED] =
+    g_signal_new("metadata-key-added",
+                 G_TYPE_FROM_CLASS(klass),
+                 G_SIGNAL_RUN_FIRST | G_SIGNAL_ACTION,
+                 0,
+                 NULL,
+                 NULL,
+                 g_cclosure_marshal_VOID__STRING,
+                 G_TYPE_NONE, 1, G_TYPE_STRING);
 }
 
 static void
@@ -176,7 +190,7 @@ grl_registry_init (GrlRegistry *registry)
   registry->priv = GRL_REGISTRY_GET_PRIVATE (registry);
 
   registry->priv->configs =
-    g_hash_table_new_full (g_str_hash, g_str_equal, g_free, g_object_unref);
+    g_hash_table_new_full (g_str_hash, g_str_equal, g_free, (GDestroyNotify) configs_free);
   registry->priv->plugins =
     g_hash_table_new_full (g_str_hash, g_str_equal, g_free, g_object_unref);
   registry->priv->sources =
@@ -184,79 +198,21 @@ grl_registry_init (GrlRegistry *registry)
   registry->priv->related_keys =
     g_hash_table_new_full (g_direct_hash, g_direct_equal, NULL, NULL);
   registry->priv->system_keys =
-    g_param_spec_pool_new (FALSE);
+    g_hash_table_new_full (g_str_hash, g_str_equal, NULL, (GDestroyNotify) g_param_spec_unref);
 
   key_id_handler_init (&registry->priv->key_id_handler);
 
   grl_registry_setup_ranks (registry);
 }
 
-static void
-grl_registry_finalize (GObject *object)
-{
-  GHashTableIter iter;
-  GList *each_key;
-  GList *related_keys = NULL;
-  GrlPlugin *plugin = NULL;
-  GrlRegistry *registry = GRL_REGISTRY (object);
-  GrlSource *source = NULL;
-
-  if (registry->priv->sources) {
-    g_hash_table_iter_init (&iter, registry->priv->sources);
-    while (g_hash_table_iter_next (&iter, NULL, (gpointer *) &source)) {
-      g_object_unref (source);
-    }
-    g_hash_table_unref (registry->priv->sources);
-    registry->priv->sources = NULL;
-  }
-
-  if (registry->priv->plugins) {
-    g_hash_table_iter_init (&iter, registry->priv->plugins);
-    while (g_hash_table_iter_next (&iter, NULL, (gpointer *) &plugin)) {
-      shutdown_plugin (plugin);
-    }
-    g_hash_table_unref (registry->priv->plugins);
-    registry->priv->plugins = NULL;
-  }
-
-  if (registry->priv->ranks) {
-    g_hash_table_unref (registry->priv->ranks);
-    registry->priv->configs = NULL;
-  }
-
-  if (registry->priv->configs) {
-    g_hash_table_unref (registry->priv->configs);
-    registry->priv->configs = NULL;
-  }
-
-  /* We need to free this table with care. Several keys can be pointing to the
-     same value, so we need to ensure that we only free the value once */
-  if (registry->priv->related_keys) {
-    while (TRUE) {
-      g_hash_table_iter_init (&iter, registry->priv->related_keys);
-      if (!g_hash_table_iter_next (&iter, NULL, (gpointer *) &related_keys)) {
-        break;
-      }
-      /* This will invalidate the iterator */
-      for (each_key = related_keys; each_key; each_key = g_list_next (each_key)) {
-        g_hash_table_remove (registry->priv->related_keys, GRLKEYID_TO_POINTER (each_key->data));
-      }
-      g_list_free (related_keys);
-    }
-    g_hash_table_unref (registry->priv->related_keys);
-    registry->priv->related_keys = NULL;
-  }
-
-  g_slist_free_full (registry->priv->plugins_dir, (GDestroyNotify) g_free);
-  g_slist_free_full (registry->priv->allowed_plugins, (GDestroyNotify) g_free);
-
-  key_id_handler_free (&registry->priv->key_id_handler);
-
-  G_OBJECT_CLASS (grl_registry_parent_class)->finalize (object);
-}
-
 /* ================ Utitilies ================ */
 
+static void
+configs_free (GList *configs)
+{
+  g_list_free_full (configs, g_object_unref);
+}
+
 static void
 config_source_rank (GrlRegistry *registry,
                     const gchar *source_id,
@@ -494,7 +450,7 @@ grl_registry_preload_plugin (GrlRegistry *registry,
 
     g_hash_table_insert (registry->priv->plugins,
                          id,
-                         g_object_ref (plugin));
+                         plugin);
   }
   return plugin;
 }
@@ -574,6 +530,46 @@ grl_registry_load_plugin_list (GrlRegistry *registry,
   return loaded_one;
 }
 
+static GrlKeyID
+grl_registry_register_metadata_key_full (GrlRegistry *registry,
+                                         GParamSpec *param_spec,
+                                         GrlKeyID key,
+                                         GError **error)
+{
+  const gchar *key_name;
+
+  g_return_val_if_fail (GRL_IS_REGISTRY (registry), 0);
+  g_return_val_if_fail (G_IS_PARAM_SPEC (param_spec), 0);
+  GrlKeyID registered_key;
+
+  key_name = g_param_spec_get_name (param_spec);
+
+  registered_key = key_id_handler_add (&registry->priv->key_id_handler, key, key_name);
+
+  if (registered_key == GRL_METADATA_KEY_INVALID) {
+    GRL_WARNING ("metadata key '%s' cannot be registered", key_name);
+    g_set_error (error,
+                 GRL_CORE_ERROR,
+                 GRL_CORE_ERROR_REGISTER_METADATA_KEY_FAILED,
+                 _("Metadata key '%s' cannot be registered"),
+                 key_name);
+
+    return GRL_METADATA_KEY_INVALID;
+  }
+
+  g_hash_table_insert (registry->priv->system_keys,
+                       (gpointer) key_name,
+                       g_param_spec_ref (param_spec));
+
+  /* Each key is related to itself */
+  g_hash_table_insert (registry->priv->related_keys,
+                       GRLKEYID_TO_POINTER (registered_key),
+                       g_list_prepend (NULL,
+                                       GRLKEYID_TO_POINTER (registered_key)));
+
+  return registered_key;
+}
+
 static void
 key_id_handler_init (struct KeyIDHandler *handler)
 {
@@ -705,8 +701,7 @@ grl_registry_restrict_plugins (GrlRegistry *registry,
 
   /* Free previous list */
   if (registry->priv->allowed_plugins) {
-    g_slist_foreach (registry->priv->allowed_plugins, (GFunc) g_free, NULL);
-    g_slist_free (registry->priv->allowed_plugins);
+    g_slist_free_full (registry->priv->allowed_plugins, g_free);
     registry->priv->allowed_plugins = NULL;
   }
 
@@ -717,6 +712,66 @@ grl_registry_restrict_plugins (GrlRegistry *registry,
   }
 }
 
+/*
+ * grl_registry_shutdown:
+ * @registry: the registry instance
+ *
+ * Frees all the resources in the registry and the registry itself.
+ **/
+void
+grl_registry_shutdown (GrlRegistry *registry)
+{
+  GHashTableIter iter;
+  GList *each_key;
+  GList *related_keys = NULL;
+  GrlPlugin *plugin = NULL;
+  GrlSource *source = NULL;
+
+  if (registry->priv->plugins) {
+    g_hash_table_iter_init (&iter, registry->priv->plugins);
+    while (g_hash_table_iter_next (&iter, NULL, (gpointer *) &plugin)) {
+      shutdown_plugin (plugin);
+    }
+    g_clear_pointer (&registry->priv->plugins, g_hash_table_unref);
+  }
+
+  if (registry->priv->sources) {
+    g_hash_table_iter_init (&iter, registry->priv->sources);
+    while (g_hash_table_iter_next (&iter, NULL, (gpointer *) &source)) {
+      g_object_unref (source);
+    }
+    g_clear_pointer (&registry->priv->sources, g_hash_table_unref);
+  }
+
+  g_clear_pointer (&registry->priv->ranks, g_hash_table_unref);
+  g_clear_pointer (&registry->priv->configs, g_hash_table_unref);
+
+  /* We need to free this table with care. Several keys can be pointing to the
+     same value, so we need to ensure that we only free the value once */
+  if (registry->priv->related_keys) {
+    while (TRUE) {
+      g_hash_table_iter_init (&iter, registry->priv->related_keys);
+      if (!g_hash_table_iter_next (&iter, NULL, (gpointer *) &related_keys)) {
+        break;
+      }
+      /* This will invalidate the iterator */
+      for (each_key = related_keys; each_key; each_key = g_list_next (each_key)) {
+        g_hash_table_remove (registry->priv->related_keys, GRLKEYID_TO_POINTER (each_key->data));
+      }
+      g_list_free (related_keys);
+    }
+    g_clear_pointer (&registry->priv->related_keys, g_hash_table_unref);
+  }
+
+  g_slist_free_full (registry->priv->plugins_dir, (GDestroyNotify) g_free);
+  g_slist_free_full (registry->priv->allowed_plugins, (GDestroyNotify) g_free);
+
+  key_id_handler_free (&registry->priv->key_id_handler);
+  g_clear_pointer (&registry->priv->system_keys, g_hash_table_unref);
+
+  g_object_unref (registry);
+}
+
 /* ================ PUBLIC API ================ */
 
 /**
@@ -1345,14 +1400,24 @@ grl_registry_register_metadata_key (GrlRegistry *registry,
                                     GParamSpec *param_spec,
                                     GError **error)
 {
-  return grl_registry_register_metadata_key_full (registry,
-                                                  param_spec,
-                                                  GRL_METADATA_KEY_INVALID,
-                                                  error);
+  GrlKeyID key;
+
+  key = grl_registry_register_metadata_key_full (registry,
+                                                 param_spec,
+                                                 GRL_METADATA_KEY_INVALID,
+                                                 error);
+
+  if (key != GRL_METADATA_KEY_INVALID) {
+    g_signal_emit (registry, registry_signals[SIG_METADATA_KEY_ADDED],
+                   0,
+                   grl_metadata_key_get_name (key));
+  }
+
+  return key;
 }
 
 /*
- * grl_registry_register_metadata_key_full:
+ * grl_registry_register_metadata_key_system:
  *
  * This is an internal method only meant to be used to register core
  * keys.
@@ -1361,45 +1426,22 @@ grl_registry_register_metadata_key (GrlRegistry *registry,
  * grl_registry_register_metadata_key().
  */
 GrlKeyID
-grl_registry_register_metadata_key_full (GrlRegistry *registry,
-                                         GParamSpec *param_spec,
-                                         GrlKeyID key,
-                                         GError **error)
+grl_registry_register_metadata_key_system (GrlRegistry *registry,
+                                           GParamSpec *param_spec,
+                                           GrlKeyID key,
+                                           GError **error)
 {
-  const gchar *key_name;
-
-  g_return_val_if_fail (GRL_IS_REGISTRY (registry), 0);
-  g_return_val_if_fail (G_IS_PARAM_SPEC (param_spec), 0);
   GrlKeyID registered_key;
 
-  key_name = g_param_spec_get_name (param_spec);
-
-  registered_key = key_id_handler_add (&registry->priv->key_id_handler, key, key_name);
-
-  if (registered_key == GRL_METADATA_KEY_INVALID) {
-    GRL_WARNING ("metadata key '%s' cannot be registered", key_name);
-    g_set_error (error,
-                 GRL_CORE_ERROR,
-                 GRL_CORE_ERROR_REGISTER_METADATA_KEY_FAILED,
-                 _("Metadata key '%s' cannot be registered"),
-                 key_name);
-
-    return GRL_METADATA_KEY_INVALID;
-  }
-
-  g_param_spec_pool_insert (registry->priv->system_keys,
-                            param_spec,
-                            GRL_TYPE_MEDIA);
-  /* Each key is related to itself */
-  g_hash_table_insert (registry->priv->related_keys,
-                       GRLKEYID_TO_POINTER (registered_key),
-                       g_list_prepend (NULL,
-                                       GRLKEYID_TO_POINTER (registered_key)));
+  registered_key = grl_registry_register_metadata_key_full (registry,
+                                                            param_spec,
+                                                            key,
+                                                            error);
+  g_param_spec_unref (param_spec);
 
   return registered_key;
 }
 
-
 /**
  * grl_registry_register_metadata_key_relation:
  * @registry: the plugin registry
@@ -1518,10 +1560,8 @@ grl_registry_lookup_metadata_key_desc (GrlRegistry *registry,
   if (!key_name) {
     return NULL;
   }
-  key_pspec = g_param_spec_pool_lookup (registry->priv->system_keys,
-                                        key_name,
-                                        GRL_TYPE_MEDIA,
-                                        FALSE);
+  key_pspec = g_hash_table_lookup (registry->priv->system_keys, key_name);
+
   if (key_pspec) {
     return g_param_spec_get_blurb (key_pspec);
   } else {
@@ -1553,10 +1593,8 @@ grl_registry_lookup_metadata_key_type (GrlRegistry *registry,
   if (!key_name) {
     return G_TYPE_INVALID;
   }
-  key_pspec = g_param_spec_pool_lookup (registry->priv->system_keys,
-                                        key_name,
-                                        GRL_TYPE_MEDIA,
-                                        FALSE);
+  key_pspec = g_hash_table_lookup (registry->priv->system_keys, key_name);
+
   if (key_pspec) {
     return G_PARAM_SPEC_VALUE_TYPE (key_pspec);
   } else {
@@ -1593,10 +1631,8 @@ grl_registry_metadata_key_validate (GrlRegistry *registry,
   if (!key_name) {
     return FALSE;
   }
-  key_pspec = g_param_spec_pool_lookup (registry->priv->system_keys,
-                                        key_name,
-                                        GRL_TYPE_MEDIA,
-                                        FALSE);
+  key_pspec = g_hash_table_lookup (registry->priv->system_keys, key_name);
+
   if (key_pspec) {
     return !g_param_value_validate (key_pspec, value);
   } else {
@@ -1817,12 +1853,8 @@ grl_registry_add_config_from_resource (GrlRegistry *registry,
   }
 
 bail:
-  if (keyfile) {
-    g_key_file_free (keyfile);
-  }
-  if (bytes) {
-    g_bytes_unref (bytes);
-  }
+  g_clear_pointer (&keyfile, g_key_file_free);
+  g_clear_pointer (&bytes, g_bytes_unref);
 
   return ret;
 }
