@@ -50,4 +50,6 @@ gchar *grl_core_keys[] = {
 "GRL_METADATA_KEY_DIRECTOR",
 "GRL_METADATA_KEY_ORIGINAL_TITLE",
 "GRL_METADATA_KEY_SIZE",
+"GRL_METADATA_KEY_TITLE_FROM_FILENAME",
+"GRL_METADATA_KEY_MB_ALBUM_ID",
 };
